package com.prolog.rdc.tms.app.service;

import java.util.List;

import com.prolog.rdc.tms.app.model.dto.PendingPickUpDetailQueryDTO;
import com.prolog.rdc.tms.app.model.dto.PendingPickUpQueryDTO;
import com.prolog.rdc.tms.app.model.dto.PendingPickUpTakeNumberDTO;
import com.prolog.rdc.tms.app.model.dto.WarehousePickUpNumberDataDTO;
import com.prolog.rdc.tms.app.model.vo.PendingPickUpDetailQueryVO;
import com.prolog.rdc.tms.app.model.vo.PendingPickUpQueryVO;
import com.prolog.rdc.tms.app.model.vo.PendingPickUpSignInVO;
import com.prolog.rdc.tms.app.model.vo.PendingPickUpStartShipmentVO;
import com.prolog.rdc.tms.app.model.vo.PendingPickUpTakeNumberVO;
import com.prolog.rdc.tms.app.model.vo.TakeNumberByShipbillVO;
import com.prolog.rdc.tms.app.model.vo.WarehousePickUpNumberDataVO;

/**
 *
 * 司机APP-待提货服务层
 *
 * @className :PendingPickUpService
 * @author :qian.yh
 * @date :2022/7/5
 * @description :
 * @version :1.0.0
 */
public interface PendingPickUpService {

	List<PendingPickUpQueryDTO> pendingPickUpQuery(PendingPickUpQueryVO pendingPickUpQueryVO) throws Exception;

	List<PendingPickUpDetailQueryDTO> pendingPickUpDetailQuery(PendingPickUpDetailQueryVO pendingPickUpDetailQueryVO) throws Exception;

	void pendingPickUpSignIn(PendingPickUpSignInVO pendingPickUpSignInVO) throws Exception;

	PendingPickUpTakeNumberDTO pendingPickUpTakeNumber(PendingPickUpTakeNumberVO pendingPickUpTakeNumberVO) throws Exception;

	List<PendingPickUpDetailQueryDTO> pendingPickUpStartShipment(PendingPickUpStartShipmentVO pendingPickUpStartShipmentVO) throws Exception;

	WarehousePickUpNumberDataDTO warehousePickUpNumberData(WarehousePickUpNumberDataVO queryvo) throws Exception;

	PendingPickUpTakeNumberDTO takeNumberByShipbill(TakeNumberByShipbillVO vo) throws Exception;
}
